%if 0%{?_version:1}
%define _verstr      %{_version}
%else
%define _verstr      0.0.25
%endif

# does this release have the server?
%if 0%{?rhel} < 10
%define with_server 1
%else
%define with_server 0
%endif

# openvox-server 7 still runs a ruby 1.9.3 kind JRuby
# remove the version pins once moving to openvox 8
%define gems trocla iuid base32 ip formatador systemu hashdiff open4 acme-client:2.0.9 public_suffix:4.0.6 ed25519
# we don't need sinatra nor openoffice in jruby
%define mrionly_gems sinatra:2.1.0 simpleidn sha3
# we want the jruby version of pg
%define jrubyonly_gems sha3-pure-ruby

%define checkout %(date +%Y%m%d)

%define puppetbindir /opt/puppetlabs/bin
%define agentdir /opt/puppetlabs/puppet
%define agentgemdir %{agentdir}/lib/ruby/gems/2.7.0/
%define servergemdir /opt/puppetlabs/server/data/puppetserver/jruby-gems

Name:		openvox7-extensions
Version:	%{_verstr}
Release:	1
Summary:	Extension for the openvox-agent or openvoxserver < 8.0.
License:	GPLv3
Source0: puppetserver.conf
Patch0: https://github.com/duritong/ip/commit/0cf261fa2fb75113c94fef5ac231f3d7b2f3ff4c.patch

BuildRequires: openvox-agent >= 7.7, openvox-agent < 8.0
%if 0%{?with_server} > 0
BuildRequires: openvox-server >= 7.2, openvox-server < 8.0
BuildRequires: postgresql
BuildRequires: postgresql-devel
%endif
BuildRequires: libxml2-devel
BuildRequires: libxslt-devel
BuildRequires: gcc-c++
BuildRequires: chrpath
Requires: openvox-agent >= 7.7

%description

A set of gems for openvox agent & server < 8.0


%filter_requires_in %agentgemdir
%filter_setup

%package -n openvox7-agent-extensions
Summary: Extension for the openvox-agent.
Requires: openvox-agent >= 7.0, openvox-agent < 8.0
%description -n openvox7-agent-extensions

A set of gem extensions packaged for the openvox-agent.

%if 0%{?with_server} > 0
%package -n openvox7-server-extensions
Summary: Extension for the openvox-server.
Requires: openvox-server >= 7.0, openvox-server < 8.0
%description -n openvox7-server-extensions

A set of gem extensions packaged for the openvox-server.
%endif

%prep

%if 0%{?with_server} > 0
mkdir server_config
cp %{SOURCE0} server_config
%endif
mkdir -p ~/.puppetlabs/etc/puppet
echo -e "[master]\nconfdir=~/puppet\ncodedir=~/puppetcode" > ~/.puppetlabs/etc/puppet/puppet.conf

%build

/opt/puppetlabs/puppet/bin/gem install --lock --install-dir ./agent_gems --no-document -N %{gems} %{mrionly_gems}

%if 0%{?with_server} > 0
# so it picks up the right config
export JAVA_BIN=/usr/bin/java
export JAVA_ARGS='-Xms2g -Xmx2g -Djruby.logger.class=com.puppetlabs.jruby_utils.jruby.Slf4jLogger'
export USER=puppet
export GROUP=puppet
export INSTALL_DIR=/opt/puppetlabs/server/apps/puppetserver
export SERVICE_STOP_RETRIES=60
export START_TIMEOUT=300
export RELOAD_TIMEOUT=120
export CLASSPATH=${INSTALL_DIR}/puppet-server-release.jar
export JRUBY_JAR="${JRUBY_JAR:-${INSTALL_DIR}/jruby-9k.jar}"
export CLASSPATH="${CLASSPATH}:${JRUBY_JAR}"
export CONFIG=./server_config
"${JAVA_BIN}" $JAVA_ARGS_CLI -Djava.security.egd=/dev/urandom \
    -cp "$CLASSPATH" \
    clojure.main -m puppetlabs.puppetserver.cli.gem \
     --config ./server_config -- install --lock --install-dir ./server_gems --no-document -N %{gems} %{jrubyonly_gems}
%endif

cd ./agent_gems/gems/ip-*
patch -p1 < %{PATCH0}
cd ../../../
%if 0%{?with_server} > 0
cd ./server_gems/gems/ip-*
patch -p1 < %{PATCH0}
cd ../../../
%endif

# remove unused files with broken shebang
rm -rf ./agent_gems/gems/*/gems/rack-*/test/
%if 0%{?with_server} > 0
rm -rf ./server_gems/gems/rack-*/test
# we don't need them
rm -rf ./server_gems/bin/{iuid,trocla}
%endif

for gem in $(find %{agentgemdir}/gems -mindepth 1 -maxdepth 1 -type d -exec basename {} \;) ; do
  find ./agent_gems/ -maxdepth 2 -name "${gem}*" -exec rm -rf {} \;
done

%if 0%{?with_server} > 0
for gem in $(find %{servergemdir}/gems -mindepth 1 -maxdepth 1 -type d -exec basename {} \;) ; do
  find ./server_gems/ -maxdepth 2 -name "${gem}*" -exec rm -rf {} \;
done
%endif

%install
mkdir -p %{buildroot}%{agentgemdir} %{buildroot}%{puppetbindir}
for d in specifications gems extensions; do
  mv ./agent_gems/${d} %{buildroot}%{agentgemdir}/
done
mv ./agent_gems/bin %{buildroot}%{agentdir}/bin
pushd %{buildroot}%{puppetbindir}
ln -sf %{agentdir}/bin/trocla
ln -sf %{agentdir}/bin/iuid
popd

%if 0%{?with_server} > 0
mkdir -p %{buildroot}%{servergemdir}
for d in bin specifications gems; do
  mv ./server_gems/${d} %{buildroot}%{servergemdir}/
done
%endif

chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/extensions/x86_64-linux/*/bcrypt-*/bcrypt_ext.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/extensions/x86_64-linux/*/ed25519-*/ed25519_ref10.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/extensions/x86_64-linux/*/sha3-*/sha3_ext.so

chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/bcrypt-*/ext/mri/bcrypt_ext.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/bcrypt-*/lib/bcrypt_ext.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/ed25519-*/ext/ed25519_ref10/ed25519_ref10.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/ed25519-*/lib/ed25519_ref10.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/sha3-*/ext/sha3/sha3_ext.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/sha3-*/lib/sha3_ext.so

%files -n openvox7-agent-extensions
%defattr(0644,root,root,0755)
%{puppetbindir}/trocla
%{puppetbindir}/iuid
%attr(0755,-,-) %{agentdir}/bin/trocla
%attr(0755,-,-) %{agentdir}/bin/iuid
%attr(0755,-,-) %{agentdir}/bin/rackup
%attr(0755,-,-) %{agentdir}/bin/tilt
%{agentgemdir}/specifications/*
%{agentgemdir}/extensions/*
%{agentgemdir}/gems/*

%if 0%{?with_server} > 0
%files -n openvox7-server-extensions
%defattr(0644,root,root,0755)
%{servergemdir}/*
%endif

%changelog

